hatch_fancy_pypi_readme: Fancy PyPI READMEs with Hatch
======================================================

Description
-----------

Fancy PyPI READMEs with Hatch

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/hatch-fancy-pypi-readme/

